﻿using System;
using System.Linq;

using IdeaBlade.EntityModel;
using IdeaBlade.Core;

namespace DomainModel {

  public partial class Customer {

    // Use this factory method template to create new instances of this class
    public static Customer Create(EntityManager manager, string companyName) {
      Customer aCustomer = manager.CreateEntity<Customer>();
      aCustomer.CustomerID = System.Guid.NewGuid();
      aCustomer.CompanyName = companyName;
      aCustomer.EntityAspect.AddToManager();
      return aCustomer;
    }

    // Delete all orders for this customer.
    public void DeleteGraph() {
      bool isPending = this.Orders.IsPendingEntityList;
      if (isPending) {
        this.Orders.PendingEntityListResolved += Orders_PendingEntityListResolved;
      } else {
        DeleteGraphCore();
      }
    }

    private void DeleteGraphCore() {
      foreach (var order in this.Orders.ToList()) {
        order.DeleteGraph();
      }
      this.EntityAspect.Delete();
    }

    private void Orders_PendingEntityListResolved(object sender, PendingEntityListResolvedEventArgs<Order> e) {
      DeleteGraphCore();
    }
  }
}
